@@ -4,9 +4,8 @@
 	beta , beta.fixed , ndim , variance.fixed , G , irtmodel ,
 	B_orig=NULL , B.fixed , E , est.variance , resp ,
 		est.slopegroups=NULL ){
-# 2PL estimation
-# c("2PL","GPCM","GPCM.design","2PL.groups") )	
-
+	# 2PL estimation
+	# c("2PL","GPCM","GPCM.design","2PL.groups") )	
   #***Model parameters
   ic <- data.frame("n" = nstud , "deviance" = deviance )
   dev <- deviance
@@ -64,13 +63,13 @@
 			resp.ind , rprobs,n.ik,pi.k){
 	item1 <- data.frame( "item" = colnames(resp) )
 	item1$N <- colSums(resp.ind )
-	item1$M <- colSums( resp.ind * resp , na.rm=T) / colSums( resp.ind )
+	item1$M <- colSums( resp.ind * resp , na.rm=TRUE) / colSums( resp.ind )
 	#****
 	# Item fit
 	# probs ... [ classes , items , categories ]
 	probs <- aperm( rprobs , perm=c(3,1,2))
 	pi.k <- matrix( pi.k , ncol=1 )
-	res <- .tam.itemfit.rmsea( n.ik , pi.k , probs )
+#	res <- .tam.itemfit.rmsea( n.ik , pi.k , probs )
 	#####
 	# Exploratory analyses show that item fit rmsea
 	# does not seem to be sensitive
@@ -82,7 +81,8 @@
 		for (dd in 1:ndim){
 			item1[ , paste0("B.Cat" , kk,".Dim",dd) ] <- B[,kk+1,dd]
 							}
-					}					
+					}
+    item1 <- item1[ item1$N > 0 , ]					
 	return(item1)
 		}
 #######################################################
